@@ -1,15 +1,12 @@
 $VAR1 = [
-    {
-        'text'    => 'Kontakt',
+    {   'text'    => 'Kontakt',
         'href'    => 'mailto:dirk.lindner@gmx.de',
         'subtree' => [],
         'rid'     => 1
     },
-    {
-        'text'    => 'Projects',
+    {   'text'    => 'Projects',
         'subtree' => [
-            {
-                'text'    => 'Empty Folder',
+            {   'text'    => 'Empty Folder',
                 'subtree' => [],
                 'rid'     => 3
             }
